#include "UserAbstractButton.h"

UserAbstractButton::UserAbstractButton(QWidget *parent)
    : QAbstractButton(parent)
{
}

void UserAbstractButton::setText(const QString &text)
{
    QAbstractButton::setText(text);

    if (isDarkTheme() && icon().isNull()) {
        setStyleSheet("background-color: #ccc");
    }
}

void UserAbstractButton::setIcon(const QIcon &icon)
{
    QAbstractButton::setIcon(icon);

    // invert the icon color
    if (isDarkTheme()) {
        QPixmap pixmap = icon.pixmap(iconSize());
        auto image = pixmap.toImage();
        image.invertPixels();
        pixmap = QPixmap::fromImage(image);

        QAbstractButton::setIcon(pixmap);
    }
}

bool UserAbstractButton::isDarkTheme() const
{
    QPalette defaultPalette;
    const auto text = defaultPalette.color(QPalette::WindowText);
    const auto window = defaultPalette.color(QPalette::Window);

    return text.lightness() > window.lightness();
}
